@@ -40,8 +40,8 @@ if(!isGeneric("screeplot"))
 if(!isGeneric("biplot"))
     setGeneric("biplot", function(x, ...) standardGeneric("biplot"))
 
-if(!isGeneric("scoreplot"))
-    setGeneric("scoreplot", function(x, ...) standardGeneric("scoreplot"))
+if(!isGeneric("scorePlot"))
+    setGeneric("scorePlot", function(x, ...) standardGeneric("scorePlot"))
 
 if(!isGeneric("getQuan"))
     setGeneric("getQuan", function(obj) standardGeneric("getQuan"))         # returns the number of observations used
